@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -23,13 +23,21 @@
 #include "Error.h"
 
 Error::Error(QString s)
-	: text(s)
 {
+	text = s;
+	callId = -1;
 }
 
 Error::Error(char *s)
-	: text(s)
 {
+	text = QString(s);
+	callId = -1;
+}
+
+Error::Error(int id, QString s)
+{
+	text = s;
+	callId = id;
 }
 
 Error::Error(error_type type)
@@ -49,7 +57,22 @@ Error::~Error()
 {
 }
 
-QString& Error::getText(void)
+QString& Error::getText()
 {
 	return text;
 }
+
+const char* Error::getError()
+{
+	return text.ascii();
+}
+
+void Error::setCallId(int id)
+{
+	callId = id;
+}
+
+int Error::getCallId()
+{
+	return callId;
+}
