@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -34,13 +34,18 @@ public:
 
 	enum error_type { IHU_ERR_MEMORY = 1 };
 	
-	Error(QString s);
-	Error(char *s);
+	Error(QString);
+	Error(char *);
 	Error(error_type);
+	Error(int, QString);
 	~Error();
-	QString& getText(void);
+	QString& getText();
+	const char* getError();
+	int getCallId();
+	void setCallId(int);
 private:
 	QString text;
+	int callId;
 };
 
 #endif
