@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -32,11 +32,10 @@
 #include <qtimer.h>
 
 #include "Config.h"
-#include "Receiver.hpp"
-#include "Transmitter.hpp"
-#include "Player.hpp"
-#include "Recorder.hpp"
+#include "PlayerDialog.hpp"
+#include "Phone.hpp"
 #include "Logger.h"
+#include "CallTab.hpp"
 #include "Rsa.h"
 
 #include "trayicon.hpp"
@@ -54,6 +53,9 @@ class QComboBox;
 class QPushButton;
 class QSlider;
 class QToolButton;
+class QTabWidget;
+class QProgressBar;
+class QStatusBar;
 
 class LogViewer;
 
@@ -62,126 +64,131 @@ class Ihu : public QMainWindow
 	Q_OBJECT
 
 public:
-	Ihu( QWidget* parent = 0, const char* name = 0, WFlags fl = WType_TopLevel );
+	Ihu( Config&, QWidget* parent = 0, const char* name = 0, WFlags fl = WType_TopLevel );
 	~Ihu();
 	
-	enum icon_type { IHU_ICON_NORMAL = 0, IHU_ICON_WAIT, IHU_ICON_ALARM, IHU_ICON_MISSED, IHU_ICON_TALK };
+	enum icon_type { IHU_ICON_NORMAL = 0, IHU_ICON_WAIT, IHU_ICON_ALARM, IHU_ICON_TALK };
 
 	QStatusBar* statusbar;
-	QWidget *lockWidget;
-	QFrame *mainFrame;
+	QTabWidget *callWidget;
+	QFrame *callFrame;
+	QFrame *waitFrame;
 	QFrame *otherFrame;
-	QLabel* tx;
-	QLabel* rx;
 	QLabel* threshold;
 	QLabel* trafficLabel;
-	QComboBox* hostEdit;
-	QLabel* hostname;
-	QLabel* agcLabel;
-	QPushButton* callButton;
-	QPushButton* stopButton;
+	QLabel* soundLabel;
+	QLabel* delayLabel;
 	QPushButton* waitButton;
-	QPushButton* logButton;
 	QSlider* thSlider;
-	QSlider* agcSlider;
-	QToolButton* ringButton;
-	QPushButton* settingsButton;
+	QProgressBar* soundLevel;
 	QToolButton* muteSpkButton;
 	QToolButton* muteMicButton;
 	QMenuBar *menubar;
 	QPopupMenu *fileMenu;
+	QPopupMenu *callMenu;
 	QPopupMenu *optionsMenu;
 	QPopupMenu *helpMenu;
+	QAction* newCallAction;
+	QAction* closeCallAction;
+	QAction* filePlayFileAction;
+	QAction* logAction;
+	QAction* clearhAction;
+	QAction* clearmAction;
 	QAction* fileQuitAction;
 	QAction* helpContentsAction;
 	QAction* helpAboutAction;
 	QAction* settingsAction;
-	QAction* filePlayFileAction;
-	QAction* fileConvertFileAction;
 	QAction* adrAction;
 	QAction* agcAction;
 	QAction* cryptAction;
 	QAction* changeKeyAction;
 	QAction* setDecKeyAction;
-	Player *player;
-	Receiver *receiver;
-	Recorder *recorder;
-	Transmitter *transmitter;
-	Rsa *rsa;
+	QAction* dumpRXAction;
+	QAction* dumpTXAction;
+	PlayerDialog *playerDialog;
+	Phone* phone;
 	Logger *logger;
-	QLabel *lockPixmap;
-	QLabel *rxPixmap;
-	QLabel *txPixmap;
 	QTimer *timer;
-	QTimer *restartTimer;
 	LogViewer* logViewer;
 	TrayIcon* trayIcon;
+
+	int maxcalls;
+	CallTab **callTab;
+
 public slots:
-	virtual void initIhu(bool);
+	virtual void initIhu();
 	virtual void closeEvent(QCloseEvent *);
 	virtual void toggleVisibility();
 	virtual void trayMenuRequested( const QPoint& );
 	virtual void changeTrayIcon(icon_type);
-	virtual void fileQuit();
+	virtual void quit();
 	virtual void helpContents();
 	virtual void helpAbout();
-	virtual void log();
+	virtual void showLogViewer();
+	virtual void clearHistory();
+	virtual void clearMissed();
 	virtual void settings();
-	virtual void waitCalls(bool);
-	virtual void waitForCalls();
-	virtual void answer();
-	virtual void call(QString);
-	virtual void startAll();
-	virtual void stopAll();
-	virtual void stop();
-	virtual void stopSignal();
-	virtual void adrOn(bool);
-	virtual void agcOn(bool);
+	virtual void adrOn();
+	virtual void agcOn();
 	virtual void adrRefresh(bool);
 	virtual void agcRefresh(bool);
-	virtual void cryptOn();
-	virtual void crypt(bool);
-	virtual bool changeKey();
+	virtual void crypt();
+	virtual void crypt(int, bool);
+	virtual void changeKey();
+	virtual bool changeKey(int);
 	virtual void setDecryptionKey();
-	virtual void agcSliderChanged(int);
-	virtual void sliderChanged(int);
-	virtual void play();
-	virtual void convert();
-	virtual void playFile(QString);
-	virtual void abortAll(QString);
+	virtual void setDecryptionKey(int);
+	virtual void enableRecorder(bool);
+	virtual void enablePlayer(bool);
+	virtual void thSliderChanged(int);
+	virtual void showPlayer();
 	virtual void showMessageCritical(QString);
 	virtual void showWarning(QString);
 	virtual void message(QString);
-	virtual void ringMessage();
+	virtual void message(int, QString);
 	virtual void warning(QString);
-	virtual void sendKey();
-	virtual void sendKeyRequest();
-	virtual void newConnection(int, int, struct sockaddr_in);
-	virtual void transmitterStatus(bool);
-	virtual void receiverStatus(bool);
-	virtual void ringOn(bool);
-	virtual void changeProgress(int);
-	virtual void sliderPress();
-	virtual void sliderRelease();
-	virtual void txLedEnable(bool);
-	virtual void rxLedEnable(bool);
+	virtual void warning(int, QString);
+	virtual void recorderStatus(bool);
+	virtual void playerStatus(bool);
 	virtual void applySettings();
+	virtual void playFile(QString);
+	virtual void toCrypt(int);
+	virtual void cryptOn();
 	virtual void disableIn();
 	virtual void disableOut();
-	virtual void listen();
-	virtual void receivedNewKey(QString);
+	virtual void receivedNewKey(int, QString);
+	virtual void receivedCall(int);
+	virtual void connectedCall(int);
+	virtual void menuUpdate();
+	virtual void dumpRXEnable();
+	virtual void dumpTXEnable();
+	virtual QString getFileName();
+	virtual void waitButtonClicked();
+	virtual void waitForCalls();
+
+	virtual void answerCall(int);
+	virtual void call(QString);
+	virtual void call(int, QString);
+	virtual void stopCall(int);
+	virtual void cancelCall(int);
+	virtual void abortCall(int, QString);
+	virtual void newCall();
+	virtual void newCall(int);
+	virtual void closeCall();
+	virtual void ring(int, bool);
+	virtual void muteMic(int, bool);
+	virtual void muteSpk(int, bool);
+	virtual void abortAll(QString);
+	virtual void abortWait(QString);
+
 private:
-	bool fromFile;
-	bool ihu2spx;
-	bool sliderFree;
-	bool listening;
-	bool received;
-	bool tocrypt;
 	bool closing;
+	bool autoanswer;
+	bool autocrypt;
+	bool showkey;
 	int skipStat;
-	unsigned long seconds;
-	QString fileName;
-	Config& config;
+	Config& ihuconfig;
+	icon_type icon_status;
 
 protected slots:
 	virtual void languageChange();
