@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -29,13 +29,12 @@
 
 #include <qobject.h>
 #include <qstring.h>
+#include <qtimer.h>
 
 #include "Error.h"
 #include "Config.h"
-#include "Player.hpp"
-#include "Receiver.hpp"
-#include "Recorder.hpp"
-#include "Transmitter.hpp"
+#include "FilePlayer.hpp"
+#include "Phone.hpp"
 #include "Logger.h"
 #include "Rsa.h"
 
@@ -43,45 +42,44 @@ class IhuNoGui : public QObject
 {
 	Q_OBJECT
 public:
-	IhuNoGui();
+	IhuNoGui(Config&);
 	~IhuNoGui();
 	void initIhu();
 	void startReceiver();
 	void agcRefresh(bool);
 	void adrRefresh(bool);
 	void call(QString);
-	void stopAll();
 	void playFile(QString);
 	void cryptOn();
-	void changeKey();
+	void cryptOn(int);
 	void disableIn();
 	void disableOut();
 	void applySettings();
 	void waitForCalls();
-	void ringOn(bool);
+	void quit();
+
 private:
-	Config& config;
-	Rsa *rsa;
-	Player *player;
-	Receiver *receiver;
-	Recorder *recorder;
-	Transmitter *transmitter;
+	Config& ihuconfig;
+	FilePlayer *fileplayer;
+	Phone *phone;
 	Logger *logger;
-	bool listening;
-	bool fromFile;
-	bool muteMic;
-	bool muteSpk;
-	bool crypt;
+	QTimer *timer;
+	bool autocrypt;
+	bool showkey;
+
 public slots:
-	void newConnection(int,int,struct sockaddr_in);
-	void stopSignal();
+	void keyRequest();
+	void receivedCall(int id);
+	void connectedCall(int id);
+	void cancelCall(int id);
 	void abortAll(QString);
-	void sendKey();
-	void sendKeyRequest();
-	void warning(QString);
 	void message(QString);
-	void ringMessage();
-	void receivedNewKey(QString);
+	void message(int, QString);
+	void abortCall(int, QString);
+	void receivedNewKey(int, QString);
+	void stopFile();
+	void changeKey(int);
+	void statistics();
 };
 
 #endif
