@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -21,12 +21,17 @@
  */
 
 #include "LogViewer.hpp"
+#include <errno.h>
 
 #include <qvariant.h>
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qlabel.h>
 #include <qtextedit.h>
+#include <qfile.h>
+#include <qtextstream.h>
+#include <qfiledialog.h>
+#include <qmessagebox.h>
 
 LogViewer::LogViewer( QWidget* parent, const char* name, bool modal, WFlags fl )
     : QDialog( parent, name, modal, fl )
@@ -45,11 +50,15 @@ LogViewer::LogViewer( QWidget* parent, const char* name, bool modal, WFlags fl )
 	textLog->setFont( text_font ); 
 	
 	clearButton = new QPushButton( this, "clearButton" );
+	saveButton = new QPushButton( this, "saveButton" );
+	closeButton = new QPushButton( this, "closeButton" );
 	
 	logLayout->addWidget( textLog, 2 );
 	
 	QBoxLayout *hLayout = new QHBoxLayout( logLayout ); 
 	hLayout->addWidget(clearButton);
+	hLayout->addWidget(saveButton);
+	hLayout->addWidget(closeButton);
 	
 	languageChange();
 	resize( QSize(700, 300).expandedTo(minimumSizeHint()) );
@@ -57,6 +66,8 @@ LogViewer::LogViewer( QWidget* parent, const char* name, bool modal, WFlags fl )
 	
 	// signals and slots connections
 	connect( clearButton, SIGNAL( clicked() ), this, SLOT( clearLog() ) );
+	connect( saveButton, SIGNAL( clicked() ), this, SLOT( saveLog() ) );
+	connect( closeButton, SIGNAL( clicked() ), this, SLOT( closeLog() ) );
 }
 
 /*
@@ -75,6 +86,9 @@ void LogViewer::languageChange()
 {
 	setCaption( tr( "IHU Log Viewer" ) );
 	clearButton->setText( tr( "Clear" ) );
+	saveButton->setText( tr( "Save" ) );
+	saveButton->setIconSet( QIconSet( QPixmap::fromMimeSource( "save.png" ) ) );
+	closeButton->setText( tr( "Close" ) );
 }
 
 void LogViewer::clearLog()
@@ -86,3 +100,26 @@ void LogViewer::addLog(QString text)
 {
 	textLog->append(text);
 }
+
+void LogViewer::saveLog()
+{
+	QString name = QFileDialog::getSaveFileName("", "*.*", this, 0, "Save to file...");
+	if (!name.isEmpty())
+	{
+		FILE *logfile = fopen(name.ascii(), "a");
+		if (logfile==NULL)
+		{
+			QMessageBox::critical(this, tr("Write failed"), tr("Could not open file for writing: %1").arg(strerror(errno)) );
+		}
+		else
+		{
+			QTextStream(logfile, IO_WriteOnly) << textLog->text();
+			fclose(logfile);
+		}
+	}
+}
+
+void LogViewer::closeLog()
+{
+	hide();
+}
