@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -37,13 +37,16 @@ class LogViewer : public QDialog
 public:
 	LogViewer( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
 	~LogViewer();
-	
 	QPushButton* clearButton;
+	QPushButton* saveButton;
+	QPushButton* closeButton;
 	QTextEdit* textLog;
 
 public slots:
-	virtual void clearLog();
 	virtual void addLog(QString);
+	virtual void clearLog();
+	virtual void saveLog();
+	virtual void closeLog();
 
 protected slots:
 	virtual void languageChange();
