@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -63,19 +63,39 @@ QString Logger::log(QString text)
 	return logText;
 }
 
-QString Logger::logStopReceiver(int calls, int connections)
+QString Logger::logStartReceiver()
 {
-	return log(QString("RECEIVER STOP. Missed %1 calls (%2 connections).\n").arg(calls).arg(connections));
+	return log(QString("START WAITING FOR CALLS"));
 }
 
-QString Logger::logStop(long inBytes, long outBytes)
+QString Logger::logStopReceiver()
 {
-	return log(QString("HANG UP. %1 bytes received, %2 bytes sent.\n").arg(inBytes).arg(outBytes));
+	return log(QString("STOP WAITING FOR CALLS"));
 }
 
-QString Logger::logOutgoingCall(QString address, QString ip)
+QString Logger::logStop(QString address, long inBytes, long outBytes)
 {
-	return log(QString("Outgoing call to %1 (%2)").arg(address).arg(ip));
+	return log(QString("HANG UP with %1: %2 bytes received, %3 bytes sent").arg(address).arg(inBytes).arg(outBytes));
+}
+
+QString Logger::logOutgoingCall(QString ip, QString address)
+{
+	return log(QString("CALL to %1 (%2)").arg(ip).arg(address));
+}
+
+QString Logger::logConnectedCall(QString ip, QString callerName)
+{
+	return log(QString("CONNECTED with %1 (%2)").arg(ip).arg(callerName));
+}
+
+QString Logger::logReceivedCall(QString ip, QString callerName)
+{
+	return log(QString("INCOMING CALL from %1 (%2)").arg(ip).arg(callerName));
+}
+
+QString Logger::logAbortedCall(QString ip, QString error)
+{
+	return log(QString("ABORTED CALL with %1 (%2)").arg(ip).arg(error));
 }
 
 void Logger::flush()
