@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -31,7 +31,8 @@
 #include <stdlib.h>
 #include <qstring.h>
 
-class Logger {
+class Logger
+{
 public:
 	Logger();
 	~Logger();
@@ -40,8 +41,12 @@ public:
 	void flush();
 	QString log(QString);
 	QString logOutgoingCall(QString, QString);
-	QString logStopReceiver(int, int);
-	QString logStop(long, long);
+	QString logReceivedCall(QString, QString);
+	QString logConnectedCall(QString, QString);
+	QString logAbortedCall(QString, QString);
+	QString logStartReceiver();
+	QString logStopReceiver();
+	QString logStop(QString, long, long);
 	static QString getTime();
 private:
 	FILE *logfile;
