@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -22,7 +22,7 @@
 
 /*
  *  ARCHITECTURE OF THE PACKET
- *  
+ *
  *  A IHU packet consists of 2 parts:
  *  1) Header
  *  2) Data
@@ -33,13 +33,14 @@
  *
  *  a) SYNC Pattern (3 bytes)
  *     The pattern consists of the fixed ASCII string: "IHU"
- *  
+ *
  *  b) Packet SIZE (1 byte): unsigned char that contains
  *     the size of the packet (min size 5, max size 256)
  *
  *  c) INFO data (1 byte)
  *     It contains those informations (in order):
- *     - Speex mode (3 bits). It can be:
+ *     - OBSOLETE: still used for bakward compatibility (versions < 0.6.x)
+ *        Speex mode (3 bits). It can be:
  *        IHU_INFO_MODE_ULTRAWIDE
  *        IHU_INFO_MODE_WIDE
  *        IHU_INFO_MODE_NARROW
@@ -57,16 +58,16 @@
  *        IHU_INFO_RING_REPLY 0x3e
  *
  *  d) Data LENGTH (1 byte): unsigned char that contains
- *     the size of the following DATA part (min 0, max 251)
+ *     the size of the following DATA part (min 0, max 250)
  *
  *  THE DATA
  *
- *  This part of the packet is of variable size (min 0, max 251 bytes)
+ *  This part of the packet is of variable size (min 0, max 250 bytes)
  *  and it contains the data to be trasmitted.
  *  It can be absent (if the packet doesn't need to transmit any data) 
  *  or, can be audio data or keys for encpryption.
  *  The type of data transmitted is specified in the INFO header
- * 
+ *
  */
 
 #include "Error.h"
@@ -120,7 +121,7 @@ bool Packet::isInfo(char param)
 	return (getInfo() & param);
 }
 
-char Packet::getMode()
+char Packet::getSeq()
 {
 	return (*info & 0xc0);
 }
@@ -144,7 +145,8 @@ void Packet::crypt(Blowfish *blowfish)
 
 void Packet::decrypt(Blowfish *blowfish)
 {
-	blowfish->decrypt(dataPtr, size - HEADER_SIZE);
+	if (dataLen > 0)
+		blowfish->decrypt(dataPtr, size - HEADER_SIZE);
 }
 
 int Packet::getSize()
