@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -20,69 +20,35 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
  */
 
-#include <math.h>
-
 #include "Error.h"
 #include "Player.hpp"
 
-//Size: 2^15
-#define MAXBUFSIZE 65536
-#define TICKTIME 5
-
-#define VOL_FACTOR 4.0
-
 Player::Player()
 {
-	tempDriver = driver = PLAY_DRIVER_ALSA;
 	playback_handle = NULL;
 	adr = false;
-	agc = false;
+	ringing = false;
 	working = false;
 	readyFrames = 0;
 	frame_size = 0;
-	pSoundTouch = new SoundTouch();
-	pSoundTouch->setChannels(1);
-	pSoundTouch->setSetting(SETTING_USE_QUICKSEEK, 1);
-	pSoundTouch->setSetting(SETTING_USE_AA_FILTER, 0);
-	sampleBuffer = new SAMPLETYPE [MAXBUFSIZE];
-	timer = new QTimer(this);
-	if ((shortBuffer = (short *) malloc(MAXBUFSIZE*sizeof(short)))==NULL)
+	delay = 0.0;
+	pSoundTouch.setChannels(1);
+	pSoundTouch.setSetting(SETTING_USE_QUICKSEEK, 1);
+	pSoundTouch.setSetting(SETTING_USE_AA_FILTER, 0);
+	if ((shortBuffer = (short *) malloc(SAMPLEBUFSIZE*sizeof(short)))==NULL)
 		throw Error(Error::IHU_ERR_MEMORY);
-	if ((audioBuffer = (float *) malloc(MAXBUFSIZE*sizeof(float)))==NULL)
-		throw Error(Error::IHU_ERR_MEMORY);
-#ifdef HAVE_LIBJACK
-	jack_handle = NULL;
-	jackdata = (jack_default_audio_sample_t *)malloc(MAXBUFSIZE * sizeof(jack_default_audio_sample_t));
-	if (jackdata==NULL)
-		throw Error(Error::IHU_ERR_MEMORY);
-#endif
-	connect(timer, SIGNAL(timeout()), this, SLOT(alsa_callback()));
 }
 
 Player::~Player(void)
 {
 	end();
-	if (audioBuffer)
-		free(audioBuffer);
 	if (shortBuffer)
 		free(shortBuffer);
-#ifdef HAVE_LIBJACK
-	if (jackdata)
-		free(jackdata);
-#endif
-	delete pSoundTouch;
-	delete sampleBuffer;
 }
 
-void Player::setup(int driv, QString interf, int vol, int pre)
+void Player::setup(QString interf, int pre)
 {
-	tempDriver = driv;
 	interface = interf;
-	vol = -vol + 1;
-	if (vol > 0)
-		ringvolume = 0.0;
-	else
-		ringvolume = powf(VOL_FACTOR, (float) (vol));
 	prepackets = pre;
 	preframes = prepackets*frame_size;
 }
@@ -92,7 +58,12 @@ bool Player::isWorking()
 	return working;
 }
 
-void Player::init(unsigned int rate, int fsize)
+float Player::getDelay()
+{
+	return delay;
+}
+
+void Player::start(unsigned int rate, int fsize)
 {
 	sample_rate = rate;
 	frame_size = fsize;
@@ -100,43 +71,23 @@ void Player::init(unsigned int rate, int fsize)
 	preframes = prepackets*frame_size;
 	prebuffer = preframes;
 	
-	driver = tempDriver;
-	
-	switch(driver)
-	{
-		case PLAY_DRIVER_ALSA:
-			initAlsa(interface.ascii());
-			break;
-		case PLAY_DRIVER_JACK:
-#ifdef HAVE_LIBJACK
-			initJack();
-#else
-			throw Error(tr("IHU was compiled without Jack support for player"));
-#endif
-			break;
-	}
+	initAlsa(interface.ascii());
 
-	pSoundTouch->clear();
-	pSoundTouch->setSampleRate(rate);
+	pSoundTouch.clear();
+	pSoundTouch.setSampleRate(rate);
 
 	delay = 0.f;
-	amp = 1.0;
-	
+	ringing = false;	
 	working = true;
 }
 
 void Player::reset()
 {
 	readyFrames = 0;
-	switch(driver)
+	if (playback_handle)
 	{
-		case PLAY_DRIVER_ALSA:
-			if (playback_handle)
-			{
-				snd_pcm_drop(playback_handle);
-				snd_pcm_prepare (playback_handle);
-			}
-			break;
+		snd_pcm_drop(playback_handle);
+		snd_pcm_prepare (playback_handle);
 	}
 }
 
@@ -185,8 +136,6 @@ void Player::initAlsa(const char *interf)
 	
 	if ((err = snd_pcm_prepare (playback_handle)) < 0)
 		throw Error(tr(QString("ALSA Output: cannot prepare audio interface for use (%1)").arg(snd_strerror(err))));
-		
-	timer->start(TICKTIME, false);
 }
 
 void Player::setAdr(bool on, float min, float max, float stch)
@@ -196,21 +145,20 @@ void Player::setAdr(bool on, float min, float max, float stch)
 	{
 		minDelay = min;
 		maxDelay = max;
-		delay = (minDelay + maxDelay) / 2.f;
 		tempoChange = stch;
 		stretch = 0.f;
-		pSoundTouch->clear();
+		pSoundTouch.clear();
 	}
 }
 
-void Player::setAgc(bool on, float step, float lev, float min, float max)
+void Player::playShort(short *buffer, int frames)
 {
-	agc = on;
-	agc_step = step;
-	level = lev*lev;
-	agc_err = 0.0;
-	minamp = min;
-	maxamp = max;
+	if (ready(frames))
+	{
+		for (i=0; i<frames; i++)
+			shortBuffer[readyFrames+i] = buffer[i];
+		readyFrames += frames;
+	}
 }
 
 void Player::play(float *buffer, int frames)
@@ -224,20 +172,8 @@ void Player::play(float *buffer, int frames)
 			if (buffer[i] < -32768.f)
 				buffer[i] = -32768.f;
 		}
-		memcpy(audioBuffer + readyFrames, buffer, frames*sizeof(float));
-		switch(driver)
-		{
-			case PLAY_DRIVER_ALSA:
-				for (i=0; i<frames; i++)
-					shortBuffer[readyFrames+i] = (short) buffer[i];
-				break;
-			case PLAY_DRIVER_JACK:
-#ifdef HAVE_LIBJACK
-				for (i=0; i<frames; i++)
-					jackdata[readyFrames+i] = (jack_default_audio_sample_t) (buffer[i]/32768.f);
-#endif
-				break;
-		}
+		for (i=0; i<frames; i++)
+			shortBuffer[readyFrames+i] = (short) buffer[i];
 		readyFrames += frames;
 	}
 }
@@ -249,24 +185,13 @@ void Player::update_frames(int frames)
 		readyFrames = 0;
 	if (readyFrames > 0)
 	{
-		memcpy(audioBuffer, audioBuffer+frames, sizeof(float)*readyFrames);
-		switch(driver)
-		{
-			case PLAY_DRIVER_ALSA:
-				memcpy(shortBuffer, shortBuffer+frames, sizeof(short)*readyFrames);
-				break;
-			case PLAY_DRIVER_JACK:
-#ifdef HAVE_LIBJACK
-				memcpy(jackdata, jackdata+frames, sizeof(jack_default_audio_sample_t)*readyFrames);
-#endif
-				break;
-		}
+		memcpy(shortBuffer, shortBuffer+frames, sizeof(short)*readyFrames);
 	}
 }
 
 bool Player::ready(int frames)
 {
-	int remaining = MAXBUFSIZE - readyFrames;
+	int remaining = SAMPLEBUFSIZE - readyFrames;
 	if (remaining < frames)
 	{
 		return false;
@@ -276,82 +201,65 @@ bool Player::ready(int frames)
 
 bool Player::ready()
 {
-	return ready(MAXBUFSIZE>>4);
+	return ready(SAMPLEBUFSIZE>>4);
 }
 
-void Player::alsa_callback()
+void Player::callback()
 {
-	if (snd_pcm_delay(playback_handle, &delayNow) == 0)
+	state = snd_pcm_state(playback_handle);
+	switch(state)
 	{
-		fdel = (float) delayNow;
-		delay = 0.99 * delay + 0.01 * (fdel/sample_rate);
-#ifdef IHU_DEBUG
-		fprintf(stderr, "Delay: %f\r", delay);
-#endif
-	}
-	if (readyFrames > prebuffer)
-	{
-		err = snd_pcm_wait(playback_handle, 1000);
-		if (err < 0) // An XRUN occurred
-		{
-			prebuffer = preframes;
-			delay = (minDelay + maxDelay) / 2.f;
+		case SND_PCM_STATE_XRUN:
+			if (prebuffer == 0)
+				prebuffer = preframes;
+			delay = 0.f;
 			snd_pcm_prepare (playback_handle);
 #ifdef IHU_DEBUG
 			qWarning("ALSA: PLAYER XRUN!");
 #endif
-		}
-		else
-		{
-			err = snd_pcm_writei (playback_handle, shortBuffer, readyFrames);
-			if (err > 0)
+			break;
+		case SND_PCM_STATE_RUNNING:
+			if (snd_pcm_delay(playback_handle, &delayNow) == 0)
 			{
-				update_frames(err);
-				prebuffer = 0;
+				fdel = (float) delayNow;
+				delay = 0.99 * delay + 0.01 * (fdel/sample_rate);
 			}
-		}
+		case SND_PCM_STATE_PREPARED:
+			if (readyFrames > prebuffer)
+			{
+				if (state == SND_PCM_STATE_PREPARED)
+				{
+					delay = (minDelay+maxDelay)/2.f;
+				}
+				err = snd_pcm_writei(playback_handle, shortBuffer, readyFrames);
+				if (err > 0)
+				{
+					update_frames(err);
+					prebuffer = 0;
+				}
+			}
+			break;
+		default:
+			break;
 	}
 }
 
-void Player::ring(short *buffer, int frames)
+void Player::playInit()
 {
-	float floatBuffer[frames];
-	for(i=0;i<frames;i++)
-	{
-		floatBuffer[i] = ((float) buffer[i]) * ringvolume;
-	}
-	play(floatBuffer, frames);
+	prebuffer = frame_size;
 }
 
 void Player::put(float *buffer, int frames)
 {
 	int nSamples = frames;
-	if (agc)
-	{
-		float sample, max = 0.f;
-		for (i=0; i<frames; i++)
-		{
-			buffer[i] *= amp;
-			sample = fabs(buffer[i])/32768.f;
-			if (sample > max)
-				max = sample;
-		}
-		agc_err = 0.9*agc_err + 0.1*(level-max);
-		amp += agc_err*agc_step;
-		if (amp < minamp)
-			amp = minamp;
-		else if (amp > maxamp)
-			amp = maxamp;
-	}
-
-	if (adr)
+	if (adr && !ringing)
 	{
 		if (delay > maxDelay)
 		{
 			if (stretch <= 0.f)
 			{
 				stretch = tempoChange;
-				pSoundTouch->setTempoChange(stretch);
+				pSoundTouch.setTempoChange(stretch);
 #ifdef IHU_DEBUG
 				qWarning("delay > maxDelay");
 #endif
@@ -363,7 +271,7 @@ void Player::put(float *buffer, int frames)
 			if (stretch >= 0.f)
 			{
 				stretch = -tempoChange;
-				pSoundTouch->setTempoChange(stretch);
+				pSoundTouch.setTempoChange(stretch);
 #ifdef IHU_DEBUG
 				qWarning("delay < minDelay");
 #endif
@@ -374,7 +282,7 @@ void Player::put(float *buffer, int frames)
 			if (stretch != 0.f)
 			{
 				stretch = 0.f;
-				pSoundTouch->setTempoChange(stretch);
+				pSoundTouch.setTempoChange(stretch);
 #ifdef IHU_DEBUG
 				qWarning("delay OK");
 #endif
@@ -383,15 +291,27 @@ void Player::put(float *buffer, int frames)
 		
 		for (i = 0; i < frames; i ++)
 			sampleBuffer[i] = (short) buffer[i];
-		pSoundTouch->putSamples(sampleBuffer, frames);
-		while ((nSamples = pSoundTouch->receiveSamples(sampleBuffer, frames)) > 0)
+		pSoundTouch.putSamples(sampleBuffer, frames);
+		while ((nSamples = pSoundTouch.receiveSamples(sampleBuffer, frames)) > 0)
 		{
 			for (i = 0; i < nSamples; i ++)
 				buffer[i] = (float) sampleBuffer[i];
 			play(buffer, nSamples);
 		}
 	}
-	play(buffer, nSamples);
+	else
+		play(buffer, nSamples);
+}
+
+void Player::pause(bool on)
+{
+	int enable = 0;
+	if (on)
+		enable = 1;
+	if (playback_handle)
+	{
+		snd_pcm_pause(playback_handle, enable);
+	}
 }
 
 bool Player::flush()
@@ -403,23 +323,16 @@ bool Player::flush()
 	}
 	else
 	{
-		switch (driver)
+		if (playback_handle)
 		{
-			case PLAY_DRIVER_ALSA:
-				if (playback_handle)
-				{
-					snd_pcm_state_t state = snd_pcm_state(playback_handle);
-					switch (state)
-					{
-						case SND_PCM_STATE_RUNNING:
-							return false;
-						default:
-							break;
-					}
-				}
-				break;
-			case PLAY_DRIVER_JACK:
-				break;
+			snd_pcm_state_t state = snd_pcm_state(playback_handle);
+			switch (state)
+			{
+				case SND_PCM_STATE_RUNNING:
+					return false;
+				default:
+					break;
+			}
 		}
 	}
 	return true;
@@ -428,7 +341,6 @@ bool Player::flush()
 void Player::end()
 {
 	working = false;
-	timer->stop();
 	readyFrames = 0;
 	
 	if (playback_handle)
@@ -438,64 +350,11 @@ void Player::end()
 	}
 	playback_handle = NULL;
 	
-	pSoundTouch->clear();
-#ifdef HAVE_LIBJACK
-	endJack();
-#endif
+	pSoundTouch.clear();
+	delay = 0.f;
 }
 
-#ifdef HAVE_LIBJACK
-
-void Player::initJack()
+void Player::disableADR(bool on)
 {
-	if ((jack_handle = jack_client_new("ihu_player")) == NULL)
-		throw Error(tr("JACK: cannot connect to server. (is Jack running?)\n"));
-	if (jack_set_process_callback(jack_handle, jack_callback, (void *)this))
-		throw Error(tr("JACK: cannot set process callback."));
-	jack_out = jack_port_register(jack_handle, "Output", JACK_DEFAULT_AUDIO_TYPE, JackPortIsOutput, 0);
-	if (jack_out == NULL)
-		throw Error(tr("JACK: cannot register Output port"));
-	if (jack_activate(jack_handle))
-		throw Error(tr("JACK: cannot activate client"));
-	if (jack_connect(jack_handle, "ihu_player:Output", "alsa_pcm:playback_1"))
-		emit warning("Couldn't connect IHU player with Jack port: alsa_pcm:playback_1");
+	ringing = on;
 }
- 
-void Player::endJack()
-{
-	if (jack_handle)
-	{
-		if (jack_deactivate(jack_handle) == 0)
-			jack_client_close(jack_handle);
-	}
-	jack_handle = NULL;
-}
-
-int Player::jack_callback(jack_nframes_t nframes, void *arg)
-{
-	Player *p = (Player *)arg;
-	return (p->jack_play(nframes));
-}
-
-int Player::jack_play(jack_nframes_t frames)
-{
-	int fr = (int) frames;
-	if (readyFrames > prebuffer)
-	{
-		if (readyFrames < fr)
-		{
-			prebuffer = preframes;
-		}
-		else
-		{
-			jack_default_audio_sample_t *buf;
-			buf = (jack_default_audio_sample_t *)jack_port_get_buffer(jack_out, frames);
-			memcpy(buf, jackdata, sizeof(jack_default_audio_sample_t) * fr);
-			update_frames(fr);
-			prebuffer=0;
-		}
-	}
-	return 0;
-}
-
-#endif
