@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -31,45 +31,38 @@
 #include <stdlib.h>
 #include <qobject.h>
 #include <qstring.h>
-#include <qtimer.h>
 #include <alsa/asoundlib.h>
 
 #include <soundtouch/SoundTouch.h>
 
-#define PLAY_DRIVER_ALSA 0
-#define PLAY_DRIVER_JACK 1
+//Size: 2^15
+#define SAMPLEBUFSIZE 65536
 
 using namespace soundtouch;
 
-#ifdef HAVE_LIBJACK
-#include <jack/jack.h>
-#endif
-
 class Player: public QObject {
 	Q_OBJECT
 public:
 	Player();
-	~Player(void);
-	void init(unsigned int, int);
+	~Player();
+	void start(unsigned int, int);
 	void initAlsa(const char*);
 	bool flush();
 	void playAlsa(float *, int);
-	void play(float *, int);
+	void play(float*, int);
+	void playShort(short*, int);
 	void end();
-	void setup(int, QString, int, int);
+	void setup(QString, int);
 	bool ready();
 	bool ready(int);
 	void setAdr(bool, float, float, float);
-	void setAgc(bool, float, float, float, float);
-	void ring(short *, int);
-	void update_frames(int frames);
+	void update_frames(int);
 	bool isWorking();
+	float getDelay();
 	void reset();
-#ifdef HAVE_LIBJACK
-	void playJack(float *, int);
-	void initJack();
-	void endJack();
-#endif
+	void pause(bool);
+	void playInit();
+	void disableADR(bool);
 private:
 	int i;
 	int err;
@@ -77,10 +70,7 @@ private:
 	int frame_size;
 	snd_pcm_t *playback_handle;
 	snd_pcm_sframes_t delayNow;
-	float *audioBuffer;
-	int driver;
-	int tempDriver;
-	float ringvolume;
+	snd_pcm_state_t state;
 	float delay;
 	float minDelay;
 	float maxDelay;
@@ -88,37 +78,23 @@ private:
 	float tempoChange;
 	float fdel;
 	bool adr;
-	bool agc;
-	SoundTouch *pSoundTouch;
-	float level;
-	float amp;
-	float minamp;
-	float maxamp;
-	float agc_err;
-	float agc_step;
+	bool ringing;
 	int readyFrames;
 	int prebuffer;
 	int preframes;
 	int prepackets;
-	QTimer *timer;
 	short *shortBuffer;
 	bool working;
 	QString interface;
-	SAMPLETYPE *sampleBuffer;
-#ifdef HAVE_LIBJACK
-	jack_client_t *jack_handle;
-	jack_port_t *jack_out;
-	jack_default_audio_sample_t *jackdata;
-	static int jack_callback(jack_nframes_t , void *);
-	int jack_play(jack_nframes_t);
-#endif
+	SoundTouch pSoundTouch;
+	SAMPLETYPE sampleBuffer[SAMPLEBUFSIZE];
+
 public slots:
 	void put(float *, int);
-	void alsa_callback();
+	void callback();
 signals:
 	void suspend();
 	void warning(QString);
 };
 
 #endif
-
