@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -40,157 +40,113 @@
 #include <netdb.h>
 #include <qsocketnotifier.h>
 
-#include <speex/speex.h>
-
 #include "Config.h"
-#include "Player.hpp"
-#include "TcpServer.hpp"
 #include "Packet.h"
 #include "Rsa.h"
 #include "Blowfish.h"
-#include "Ihu2Spx.h"
 
 class Receiver: public QObject {
 	Q_OBJECT
 public:
 
-	enum receiver_status {
-		RECEIVER_STATUS_NORMAL = 0,
-		RECEIVER_STATUS_MUTE
-	};
-	
 	enum stream_status {
 		STREAM_OK = 0,
 		STREAM_OUT_OF_SYNC,
 		STREAM_MISSING_DATA,
-		STREAM_DATA,
 		STREAM_READ_DATA,
-		STREAM_PLAYER_NOT_READY
 	};
 	
 	enum signal_type {
-		SIGNAL_FINISH = 0,
+		SIGNAL_INIT = 0,
+		SIGNAL_RING,
 		SIGNAL_RINGREPLY,
 		SIGNAL_SENDNEWKEY,
 		SIGNAL_KEYREQUEST,
 		SIGNAL_NEWKEY,
+		SIGNAL_FINISH
 	};
 	
-	Receiver(Player *, Rsa *);
+	Receiver(Rsa *);
 	~Receiver(void);
 	void reset();
 	void resetStream();
-	void changeMode(char);
-	void initPlayer(receiver_status);
 	void dump(QString);
-	void waitConnection();
 	void listen(int, bool, bool);
 	void putData(char *, int);
 	void processData();
 	bool processPacket(Packet *);
-	void playData(char *, int);
-	void playFile(QString);
-	void convertFile(QString);
-	void stopFile();
 	long getBytes();
 	long getTotal();
 	void enableDecrypt(char *, int);
 	void disableDecrypt();
-	int getCalls();
-	int getConnections();
-	void resetCalls();
 	void close();
 	void stop();
 	void go();
-	void swap();
-	void startFile();
-	void changeStatus(receiver_status);
-	void ring(int);
-	void seekFile(int);
-	void ledOn(bool);
 	void noDecrypt();
 	QString getIp();
 	QString getCallerName();
-	bool refused();
 	bool replied();
+	bool refused();
+	bool aborted();
 	void emitError(QString);
-	void emitSignal(signal_type);
 	void flush();
+	bool isDumping();
+	void setConnected(bool);
+	bool isConnected();
+	void setReceived(bool);
+	bool isReceived();
+	bool isActive();
+
 private:
-	Player *player;
-	Ihu2Spx *ihu2spx;
 	int s;
-	receiver_status status;
 	stream_status sync;
-	struct sockaddr_in sa;
 	struct sockaddr_in ca;
 	socklen_t calen;
 	int port;
 	QSocketNotifier* notifier;
 	FILE *outFile;
-	FILE *inFile;
 	char *inputBuffer;
 	char *streamBuffer;
 	char *streamPtr;
-	float *outBuffer;
-	SpeexBits bits;
-	void *state;
-	int frame_size;
 	long bytes;
 	long total;
-	long packets;
-	int rate;
 	int streamLen;
 	Blowfish *blowfish;
 	Rsa *rsa;
-	char speexmode;
-	TcpServer *tcpserver;
-	short *ring_buffer;
-	int ring_size;
 	bool working;
-	bool realtime;
-	bool listening;
-	bool fromFile;
 	bool nodecrypt;
-	bool refuse;
-	bool reply;
+	bool ihu_refuse;
+	bool ihu_reply;
+	bool ihu_abort;
 	bool connected;
-	bool newconnected;
-	bool halfconnected;
+	bool received;
 	bool flushing;
-	bool playing;
-	bool spx;
-	int calls;
-	int connects;
-	QTimer *timer;
-	QTimer *fileTimer;
+	bool active;
 	QTimer *checkTimer;
 	QString callerName;
 	int protocol;
-	int read_size;
+	void emitSignal(signal_type);
+
 public slots:
-	void readFile();
 	void receive(void);
 	void end();
 	void start(int, int);
-	void checkPlayer();
-	void goRing();
 	void checkConnection();
-	void newConnection(int);
-private slots:
+
 signals:
-	void finish();
+	void finishSignal();
+	void initSignal();
+	void ringSignal();
 	void error(QString);
 	void keyRequest();
 	void sendNewKey();
 	void newKey(QString);
-	void ringReply();
+	void ringReplySignal();
 	void message(QString);
 	void warning(QString);
 	void newSocket(int,int,struct sockaddr_in);
-	void fileProgress(int);
-	void ledEnable(bool);
+	void connectedSignal();
+	void newAudioData(char*, int);
 };
 
 #endif
-
