@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -50,6 +50,8 @@ public:
 	void start(unsigned int);
 	void end(void);
 	bool isWorking();
+	void adjustVolume(float);
+	void setupAgc(bool, const char*);
 #ifdef HAVE_LIBJACK
 	void initJack();
 	void endJack();
@@ -57,6 +59,8 @@ public:
 private:
 	int err;
 	snd_pcm_t *capture_handle;
+	snd_mixer_t *mhandle;
+	snd_mixer_elem_t *elem;
 	short *samples;
 	float *audioBuffer;
 	int driver;
@@ -64,6 +68,10 @@ private:
 	bool working;
 	QString interface;
 	QTimer *timer;
+	float volume;
+	long vol_min;
+	long vol_max;
+	long vol;
 #ifdef HAVE_LIBJACK
 	jack_client_t *jack_handle;
 	jack_port_t *jack_in;
