@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -63,7 +63,7 @@ Rsa::~Rsa()
 	if (peer_public_key)
 		free(peer_public_key);
 	
-	delete my_public_key;
+	delete[] my_public_key;
 }
 
 void Rsa::RSA_generateKeys()
@@ -96,15 +96,15 @@ void Rsa::RSA_generateKeys()
 	mpz_mul(my_n,p,q);
 	
 	char *n_str = new char[bufsize];
-	mpz_get_str(n_str,16,my_n);
+	mpz_get_str(n_str, 16, my_n);
 	keylen = convert2bin(n_str, my_public_key);
 	
 	mpz_t p_minus_1,q_minus_1;
 	mpz_init(p_minus_1);
 	mpz_init(q_minus_1);
-	mpz_sub_ui(p_minus_1,p,(unsigned long int)1);
-	mpz_sub_ui(q_minus_1,q,(unsigned long int)1);
-	mpz_mul(x,p_minus_1,q_minus_1);
+	mpz_sub_ui(p_minus_1, p, (unsigned long int)1);
+	mpz_sub_ui(q_minus_1, q, (unsigned long int)1);
+	mpz_mul(x, p_minus_1, q_minus_1);
 	
 	mpz_t gcd;
 	mpz_init(gcd);
@@ -113,14 +113,14 @@ void Rsa::RSA_generateKeys()
 	
 	while(true)
 	{
-		mpz_gcd_ui(gcd,x,e_int);
-		if(mpz_cmp_ui(gcd,(unsigned long int)1)==0)
+		mpz_gcd_ui(gcd, x, e_int);
+		if(mpz_cmp_ui(gcd, (unsigned long int)1)==0)
 		break;
 		e_int += 2;
 	}
-	mpz_set_ui(e,e_int);
+	mpz_set_ui(e, e_int);
 	
-	if(mpz_invert(d,e,x)==0)
+	if(mpz_invert(d, e, x)==0)
 	{
 		RSA_generateKeys();
 	}
@@ -131,6 +131,9 @@ void Rsa::RSA_generateKeys()
 	mpz_clear(p_minus_1);
 	mpz_clear(q_minus_1);
 	mpz_clear(gcd);
+	delete[] p_str;
+	delete[] q_str;
+	delete[] n_str;
 }
 
 int Rsa::encrypt(char *data, int len, char **output)
