@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -51,7 +51,7 @@ class Settings : public QTabDialog
 	Q_OBJECT
 
 public:
-	Settings( QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
+	Settings( Config&, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
 	~Settings();
 	
 	QWidget* generalWidget;
@@ -70,13 +70,13 @@ public:
 	QButtonGroup* securityGroup;
 	QLineEdit *nameEdit;
 	QLabel* nameLabel;
-	QLabel* dumpLabel;
 	QCheckBox* answerBox;
 	QCheckBox* trayBox;
 	QCheckBox* waitBox;
 	QCheckBox* hideBox;
 	QCheckBox* udpBox;
 	QCheckBox* tcpBox;
+	QCheckBox* cryptBox;
 	QLabel* dspLabel;
 	QLabel* interfInLabel;
 	QLabel* interfOutLabel;
@@ -89,9 +89,8 @@ public:
 	QLabel* adrmaxdelayLabel;
 	QLabel* adrmindelayLabel;
 	QLabel* adrstretchLabel;
-	QLabel* agcSpeedLabel;
-	QLabel* agcminLabel;
-	QLabel* agcmaxLabel;
+	QLabel* agcStepLabel;
+	QLabel* agcLevelLabel;
 	QLabel* protocolLabel;
 	QLabel* inprotocolLabel;
 	QLabel* inportLabel;
@@ -99,11 +98,14 @@ public:
 	QLabel* stoptxLabel;
 	QLabel* ringVolumeLabel;
 	QLabel* prepacketsLabel;
+	QLabel* logNameLabel;
+	QLabel* maxCallLabel;
+	QLabel* maxHostLabel;
+	QSpinBox *maxCallBox;
+	QSpinBox *maxHostBox;
 	QSpinBox *stoptxBox;
 	QSpinBox *prepacketsBox;
 	QSpinBox *agcBox;
-	QSpinBox *agcminBox;
-	QSpinBox *agcmaxBox;
 	QSpinBox* adrmindelayBox;
 	QSpinBox* adrmaxdelayBox;
 	QSpinBox *adrstretchBox;
@@ -114,8 +116,7 @@ public:
 	QSpinBox* abrBox;
 	QSpinBox* vbrqualityBox;
 	QSlider *agcstep;
-	QPushButton* openInButton;
-	QPushButton* openOutButton;
+	QSlider *agclevel;
 	QCheckBox* vadBox;
 	QCheckBox* dtxBox;
 	QComboBox *dspBox;
@@ -124,16 +125,19 @@ public:
 	QComboBox *modeBox;
 	QComboBox *bitrateBox;
 	QComboBox *ringVolumeBox;
+	QComboBox *mixerBox;
 	QRadioButton* udpRadioButton;
 	QRadioButton* tcpRadioButton;
+	QCheckBox* agchwBox;
+	QCheckBox* agcswBox;
 	QRadioButton* randomRadioButton;
 	QRadioButton* passwordRadioButton;
 	QButtonGroup* securityButtonGroup;
 	QLabel* keyLabel;
 	QSpinBox* bitsBox;
-	QLabel* logLabel;
-	QPushButton* logButton;
+	QCheckBox* logBox;
 	QCheckBox* showkeyBox;
+	QPushButton* passButton;
 
 private:
 	QString inFile;
@@ -141,18 +145,22 @@ private:
 	QString logFile;
 
 protected:
-	Config &config;
+	Config &ihuconfig;
 
 public slots:
 	virtual void languageChange();
-	virtual void saveSettings();
+	virtual bool saveSettings();
+	virtual void saveAndClose();
+	virtual void saveToFile();
 	virtual void defaults();
-	virtual void logEnable(bool);
-	virtual void dumpinEnable(bool);
-	virtual void dumpoutEnable(bool);
+	virtual void logEnable();
 	virtual void bitrateChanged();
 	virtual void minimizeEnable(bool);
 	virtual QString fileName(QString);
+	virtual void agcLevelChanged(int);
+	virtual void agcStepChanged(int);
+	virtual void agcHwToggled(bool);
+	virtual void passButtonClicked();
 };
 
 #endif // SETTINGS_H
