@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -30,113 +30,34 @@
 
 #include "PacketHandler.h"
 
-#define MAXBUFSIZE 65536
 #define RINGTIME 3000
 
-Transmitter::Transmitter(Recorder *rec, Rsa *r)
-	: recorder(rec), rsa(r)
+Transmitter::Transmitter(Rsa *r) : rsa(r)
 {
 	setName("Transmitter");
-	s = -1;
 	salen = sizeof(sa);
-	total = bytes = 0;
-	rate = 0;
 	outFile = NULL;
-	state = NULL;
 	blowfish = NULL;
-	speexmode = 0;
-	ready = 0;
-	working = false;
-	recording = false;
-	ringing = false;
-	transmitting = false;
-	readBuffer = NULL;
-	if ((out = (char *) malloc(MAXBUFSIZE))==NULL)
-		throw Error(Error::IHU_ERR_MEMORY);
-	if ((buffer = (float *) malloc(MAXBUFSIZE*sizeof(float)))==NULL)
-		throw Error(Error::IHU_ERR_MEMORY);
-	if ((prebuffer = (float *) malloc(REC_BUFSIZE*sizeof(float)))==NULL)
-		throw Error(Error::IHU_ERR_MEMORY);
+	crypted = false;
 	timer = new QTimer(this);
+	reset();
 	connect(timer, SIGNAL(timeout()), this, SLOT(sendRing()));
-	connect(recorder, SIGNAL(data(float*, int)), this, SLOT(processData(float*,int)));
-	status = TRANSMITTER_STATUS_WAITING;
 }
 
 Transmitter::~Transmitter(void)
 {
 	if (outFile)
 		fclose(outFile);
-	if (out)
-		free(out);
-	if (buffer)
-		free(buffer);
-	if (prebuffer)
-		free(prebuffer);
-	if (state)
-		speex_encoder_destroy(state);
-	speex_bits_destroy(&bits);
 }
 
-void Transmitter::setup(int srate, int quality, int abr, int vbr, float vbr_quality, int complexity, int vad, int dtx, int txstop)
+void Transmitter::reset()
 {
-	if (recording)
-	{
-		recorder->end();
-		stop();
-	}
-
-	SpeexMode *mode = NULL;
-	
-	switch (srate)
-	{
-		case 32000:
-			mode = (SpeexMode *) &speex_uwb_mode;
-			speexmode = IHU_INFO_MODE_ULTRAWIDE;
-			break;
-		case 16000:
-			mode = (SpeexMode *) &speex_wb_mode;
-			speexmode = IHU_INFO_MODE_WIDE;
-			break;
-		case 8000:
-			mode = (SpeexMode *) &speex_nb_mode;
-			speexmode = IHU_INFO_MODE_NARROW;
-			break;
-	}
-	
-	if (state)
-		speex_encoder_destroy(state);
-	
-	state = speex_encoder_init(mode);
-
-	speex_encoder_ctl(state, SPEEX_SET_SAMPLING_RATE, &srate);
-	speex_encoder_ctl(state, SPEEX_SET_COMPLEXITY, &complexity);
-	if (vbr)
-	{
-		speex_encoder_ctl(state, SPEEX_SET_VBR, &vbr);
-		speex_encoder_ctl(state, SPEEX_SET_VBR_QUALITY, &vbr_quality);
-	}
-	else
-	{
-		speex_encoder_ctl(state, SPEEX_SET_QUALITY, &quality);
-		speex_encoder_ctl(state, SPEEX_SET_VAD, &vad);
-	}
-	if (abr)
-		speex_encoder_ctl(state, SPEEX_SET_ABR, &abr);
-	speex_encoder_ctl(state, SPEEX_SET_DTX, &dtx);
-	speex_encoder_ctl(state, SPEEX_GET_FRAME_SIZE, &frame_size);
-	
-	stoptx = (int) ((srate / frame_size)*txstop);
-	
-	speex_bits_init(&bits);
-	
-	rate = srate;
-
-	if (recording)
-	{
-		initRecorder();
-		go();
-	}
+	s = -1;
+	total = bytes = 0;
+	working = false;
+	ringing = false;
+	active = false;
+	tx = false;
 }
 
 void Transmitter::init(int prot)
@@ -146,18 +67,11 @@ void Transmitter::init(int prot)
 	memset(&sa, 0, sizeof(sa));
 	sa.sin_family = AF_INET;
 
-	speak = bytes = total = 0;
-
-	memset(out, 0, MAXBUFSIZE);
-	
-	memset(prebuffer, 0x0, sizeof(float)*REC_BUFSIZE);
-	
+	reset();
 }
 
-void Transmitter::setName(QString name)
+void Transmitter::setMyName(QString name)
 {
-	if(name.length() > IHU_MAX_NAME_LEN)
-		name.truncate(IHU_MAX_NAME_LEN);
 	myName = name;
 }
 
@@ -177,20 +91,6 @@ void Transmitter::dump(QString file)
 	}
 }
 
-void Transmitter::initRecorder()
-{
-	switch (status)
-	{
-		case TRANSMITTER_STATUS_MUTE:
-			break;
-		default:
-			ready = toRead = 0;
-			bufptr = buffer;
-			recorder->start(rate);
-			break;
-	}
-}
-
 void Transmitter::go()
 {
 	working = true;
@@ -201,40 +101,6 @@ void Transmitter::stop()
 	working = false;
 }
 
-void Transmitter::prepare()
-{
-	switch(status)
-	{
-		case TRANSMITTER_STATUS_NORMAL:
-			status = TRANSMITTER_STATUS_WAITING;
-		default:
-			sendInitPacket();
-			changeStatus(status);
-			break;
-	}
-	transmitting = true;
-}
-
-void Transmitter::changeStatus(transmitter_status newstatus)
-{
-	status = newstatus;
-	switch (status)
-	{
-		case TRANSMITTER_STATUS_MUTE:
-			recorder->end();
-			break;
-		default:
-			if (working && recording)
-			{
-				if (!recorder->isWorking())
-					initRecorder();
-				emit message("Audio input started.");
-			}
-			break;
-	}
-	ledOn(false);
-}
-
 void Transmitter::newConnection(int socket, struct sockaddr_in ca, int prot)
 {
 	init(prot);
@@ -254,7 +120,6 @@ void Transmitter::start(int socket)
 {
 	s = socket;
 	go();
-	recording = true;
 }
 
 int Transmitter::call(QString host, int port, int prot)
@@ -297,8 +162,6 @@ int Transmitter::call(QString host, int port, int prot)
 	
 	start(sd);
 	
-	initRecorder();
-	
 	return sd;
 }
 
@@ -306,16 +169,8 @@ void Transmitter::end()
 {
 	stop();
 	
-	recording = transmitting = false;
-	
 	timer->stop();
 	
-	total = 0;
-
-	recorder->end();
-	
-	if (s!=-1)
-		::close(s);
 	s = -1;
 }
 
@@ -324,6 +179,7 @@ void Transmitter::enableCrypt(char *passwd, int len)
 	disableCrypt();
 	blowfish = new Blowfish(passwd, len);
 	sendResetPacket();
+	crypted = true;
 }
 
 void Transmitter::disableCrypt()
@@ -331,65 +187,24 @@ void Transmitter::disableCrypt()
 	if (blowfish)
 		delete blowfish;
 	blowfish = NULL;
-}
-
-int Transmitter::isSpeaking(float *samples, int sample)
-{
-	int i;
-	for (i=0; i<sample; i++)
-		if (fabs(samples[i]) >= threshold)
-			return 1;
-	return 0;
-}
-
-void Transmitter::processData(float *samples, int nsample)
-{
-	readBuffer = samples;
-	while (working && (nsample > 0))
-	{
-		toRead = frame_size - ready;
-		if (nsample < toRead)
-		{
-			memcpy(bufptr, readBuffer, nsample*sizeof(float));
-			ready += nsample;
-			bufptr += nsample;
-			nsample = 0;
-			break;
-		}
-		else
-		if (nsample >= toRead)
-		{
-			memcpy(bufptr, readBuffer, toRead*sizeof(float));
-			ready += toRead;
-			bufptr += toRead;
-			readBuffer += toRead;
-			nsample -= toRead;
-			if (ready == frame_size)
-			{
-				if (transmitting)
-					send(buffer, frame_size);
-				ready = 0;
-				bufptr = buffer;
-			}
-		}
-	}
+	crypted = false;
 }
 
 void Transmitter::sendPacket(Packet *p)
 {
 	int snt = 0;
-	if (s != -1)
+	if ((s != -1) && working)
 	{
 		snt = ::send(s, p->getPacket(), p->getSize(), MSG_NOSIGNAL);
 		if (snt <= 0)
 		{
-			emit finish();
+			emitSignal(SIGNAL_FINISH);
 		}
 		else
 		{
 			bytes += snt;
 			total += snt;
-			ledOn(true);
+			active = true;
 		}
 	}
 	if (outFile) {
@@ -398,42 +213,18 @@ void Transmitter::sendPacket(Packet *p)
 	}
 }
 
-void Transmitter::send(float *sample, int samples)
+void Transmitter::prepare()
 {
-	if (isSpeaking(sample, samples)) 
-	{
-		if (status == TRANSMITTER_STATUS_WAITING)
-			status = TRANSMITTER_STATUS_START;
-		speak = stoptx; // To guarantee stream even for small speech pauses
-	}
-	switch (status)
-	{
-		case TRANSMITTER_STATUS_START:
-			sendAudioPacket(prebuffer, frame_size);
-			status = TRANSMITTER_STATUS_NORMAL;
-		case TRANSMITTER_STATUS_NORMAL:
-			if (speak > 0) {
-				sendAudioPacket(sample, samples);
-				speak--;
-				break;
-			}
-			else 
-			{
-				status = TRANSMITTER_STATUS_WAITING;
-			}
-		case TRANSMITTER_STATUS_WAITING:  // It keeps the previous buffer to anticipate a little the speech
-			memcpy(prebuffer, sample, samples*sizeof(float));
-		case TRANSMITTER_STATUS_MUTE:
-			ledOn(false);
-			break;
-	}
+	sendInitPacket();
+	tx = true;
+	emitSignal(SIGNAL_START);
 }
 
 void Transmitter::ring(bool on)
 {
 	if (on)
 	{
-		transmitting = false;
+		tx = false;
 		ringing = true;
 		sendRing();
 	}
@@ -447,9 +238,9 @@ void Transmitter::sendRing()
 {
 	if (ringing)
 	{
-		emit ringMessage();
 		timer->start(RINGTIME, true);
 		sendRingPacket();
+		emitSignal(SIGNAL_RINGMESSAGE);
 	}
 	else
 	{
@@ -464,29 +255,24 @@ void Transmitter::sendRing()
 	}
 }
 
-void Transmitter::sendAudioPacket(float *fsamples, int samples)
+void Transmitter::sendAudioPacket(char *data, int len)
 {
-	int tot = 0;
-	speex_bits_reset(&bits);
-	if (state)
+//	qWarning("Transmitter::SendAudioPacket");
+	if (tx)
 	{
-		speex_encode(state, fsamples, &bits);
-		tot = speex_bits_write(&bits, out, MAXBUFSIZE);
-	}
-	if (tot>0) {
 		int size;
 		char type = IHU_INFO_AUDIO;
 		try
 		{
 			if (blowfish)
 			{
-				size = PacketHandler::calculateCryptedSize(tot);
+				size = PacketHandler::calculateCryptedSize(len);
 				type = IHU_INFO_CRYPTED_AUDIO;
 			}
 			else
-				size = PacketHandler::calculateSize(tot);
+				size = PacketHandler::calculateSize(len);
 			Packet *p = new Packet (size);
-			PacketHandler::buildModePacket(p, out, tot, type, speexmode);
+			PacketHandler::buildModePacket(p, data, len, type, IHU_INFO_MODE_ULTRAWIDE);
 			if (blowfish)
 				p->crypt(blowfish);
 			sendPacket(p);
@@ -506,6 +292,7 @@ void Transmitter::emitError(QString text)
 
 void Transmitter::sendSpecialPacket(char *data, int len, char type)
 {
+//	qWarning("Transmitter::SendSpecialPacket");
 	try
 	{
 		int size = PacketHandler::calculateSize(len);
@@ -522,11 +309,12 @@ void Transmitter::sendSpecialPacket(char *data, int len, char type)
 
 void Transmitter::sendNewPacket(char *data, int len, char type)
 {
+//	qWarning("Transmitter::SendNewPacket");
 	try
 	{
 		int size = PacketHandler::calculateSize(len);
 		Packet *p = new Packet (size);
-		PacketHandler::buildModePacket(p, data, len, speexmode, type);
+		PacketHandler::buildModePacket(p, data, len, IHU_INFO_MODE_ULTRAWIDE, type);
 		sendPacket(p);
 		delete p;
 	}
@@ -538,6 +326,7 @@ void Transmitter::sendNewPacket(char *data, int len, char type)
 
 void Transmitter::sendNamePacket(bool special, char type)
 {
+//	qWarning("Transmitter::SendNamePacket");
 	int dataLen = 0;
 	char *dataPtr = NULL;
 	if (!myName.isEmpty())
@@ -592,6 +381,11 @@ void Transmitter::sendInitPacket()
 	sendNewPacket(NULL, 0, IHU_INFO_INIT);
 }
 
+void Transmitter::sendErrorPacket()
+{
+	sendNewPacket(NULL, 0, IHU_INFO_ERROR);
+}
+
 void Transmitter::sendKeyPacket()
 {
 	char *out;
@@ -625,16 +419,10 @@ void Transmitter::sendKeyRequestPacket()
 	sendSpecialPacket(public_key, keylen, IHU_INFO_KEY_REQUEST);
 }
 
-void Transmitter::setThreshold(int th)
-{
-	threshold = (float) (th * th * 3.2);
-}
-
 long Transmitter::getBytes()
 {
 	long temp = bytes;
 	bytes = 0;
-	ledOn(false);
 	return temp;
 }
 
@@ -648,13 +436,48 @@ QString Transmitter::getIp()
 	return QString(inet_ntoa(sa.sin_addr));
 }
 
-void Transmitter::ledOn(bool on)
-{
-	if (working)
-		emit ledEnable(on);
-}
-
 bool Transmitter::isWorking()
 {
 	return working;
 }
+
+bool Transmitter::isCrypted()
+{
+	return crypted;
+}
+
+bool Transmitter::isDumping()
+{
+	bool ret = false;
+	if (outFile)
+		ret = true;
+	return ret;
+}
+
+bool Transmitter::isActive()
+{
+	bool temp = active;
+	active = false;
+	return temp;
+}
+
+void Transmitter::emitSignal(signal_type type)
+{
+	switch(type)
+	{
+		if (working)
+		{
+			case SIGNAL_FINISH:
+				emit finishSignal();
+				break;
+			case SIGNAL_START:
+				emit startSignal();
+				break;
+			case SIGNAL_RINGMESSAGE:
+				emit ringMessage();
+				break;
+		}
+		default:
+			break;
+	}
+}
