@@ -1,7 +1,7 @@
 /*
  *  IHU -- I Hear U, easy VoIP application using Speex and Qt
  *
- *  Copyright (C) 2003-2006 Matteo Trotta - <mrotta@users.sourceforge.net>
+ *  Copyright (C) 2003-2008 Matteo Trotta - <mrotta@users.sourceforge.net>
  *
  *  http://ihu.sourceforge.net
  *
@@ -38,39 +38,34 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 
-#include <speex/speex.h>
-
-#include "Recorder.hpp"
 #include "Packet.h"
 #include "Rsa.h"
 #include "Blowfish.h"
 
 class Transmitter: public QObject {
 	Q_OBJECT
+
 public:
 
-	enum transmitter_status {
-		TRANSMITTER_STATUS_NORMAL = 0, 
-		TRANSMITTER_STATUS_START, 
-		TRANSMITTER_STATUS_WAITING, 
-		TRANSMITTER_STATUS_MUTE,
+	enum signal_type {
+		SIGNAL_FINISH = 0,
+		SIGNAL_START,
+		SIGNAL_RINGMESSAGE,
 	};
-	
-	Transmitter(Recorder *, Rsa *);
+
+	Transmitter(Rsa *);
 	~Transmitter(void);
-	void setup(int, int, int, int, float, int, int, int, int);
+	void reset();
 	void init(int);
-	void setName(QString);
+	void setMyName(QString);
 	void dump(QString);
 	void start(int);
 	int call(QString, int, int);
 	void answer();
-	void initRecorder();
 	void end();
 	void go();
 	void stop();
 	void ring(bool);
-	void send(float *, int);
 	void setThreshold(int);
 	long getBytes();
 	long getTotal();
@@ -80,67 +75,54 @@ public:
 	void sendNewPacket(char*, int, char);
 	void sendSpecialPacket(char*, int, char);
 	void sendNamePacket(bool, char);
-	void sendAudioPacket(float *, int);
+	void sendAudioPacket(char *, int);
 	void sendInitPacket();
 	void sendResetPacket();
 	void sendAnswerPacket();
 	void sendClosePacket();
 	void sendRefusePacket();
 	void sendRingPacket();
+	void sendErrorPacket();
 	void newConnection(int, struct sockaddr_in, int);
 	QString getIp();
-	void changeStatus(transmitter_status);
-	void prepare();
 	void emitError(QString);
-	void ledOn(bool);
 	bool isWorking();
+	void prepare();
+	bool isCrypted();
+	bool isDumping();
+	bool isActive();
+
 private:
-	Recorder *recorder;
-	bool working;
-	bool recording;
-	bool ringing;
-	bool transmitting;
 	int s;
 	struct sockaddr_in sa;
 	socklen_t salen;
-	char *out;
-	int speak;
-	int bufsize;
-	float threshold;
 	int port;
 	FILE *outFile;
-	void *state;
-	int frame_size;
-	SpeexBits bits;
 	long bytes;
 	long total;
-	int ready;
-	int toRead;
-	float *readBuffer;
-	unsigned int rate;
 	Blowfish *blowfish;
 	Rsa *rsa;
-	char speexmode;
-	float *buffer, *bufptr;
-	float *prebuffer;
-	transmitter_status status;
 	QString myName;
 	QTimer *timer;
 	int protocol;
-	int stoptx;
-	int isSpeaking(float *, int);
+	bool working;
+	bool ringing;
+	bool crypted;
+	bool active;
+	bool tx;
+	void emitSignal(signal_type);
+
 public slots:
-	void processData(float *, int);
 	void sendKeyRequestPacket();
 	void sendKeyPacket();
 	void sendRing();
 	void sendRingReplyPacket();
 signals:
-	void finish();
+	void finishSignal();
 	void error(QString);
 	void message(QString);
 	void ringMessage();
-	void ledEnable(bool);
+	void startSignal();
 };
 
 #endif
